]> git.proxmox.com Git - mirror_frr.git/commitdiff
*: spelchek
authorDavid Lamparter <equinox@opensourcerouting.org>
Thu, 25 Oct 2018 18:06:59 +0000 (20:06 +0200)
committerDavid Lamparter <equinox@opensourcerouting.org>
Thu, 25 Oct 2018 18:10:57 +0000 (20:10 +0200)
Signed-off-by: David Lamparter <equinox@diac24.net>
44 files changed:
babeld/babel_interface.h
babeld/babel_main.c
bgpd/bgp_attr.c
bgpd/bgp_damp.c
bgpd/bgp_errors.c
bgpd/bgp_evpn.c
bgpd/bgp_evpn_vty.c
bgpd/bgp_fsm.c
bgpd/bgp_packet.c
bgpd/bgp_vty.c
doc/manpages/common-options.rst
doc/manpages/zebra.rst
eigrpd/eigrp_const.h
eigrpd/eigrp_dump.c
eigrpd/eigrp_fsm.c
isisd/isis_spf.c
ldpd/ldp_vty_cmds.c
ldpd/util.c
lib/bfd.c
lib/command.h
lib/lib_errors.c
lib/mpls.h
lib/sockunion.c
m4/ax_sys_weak_alias.m4
ospf6d/ospf6_abr.c
ospf6d/ospf6_area.c
ospfd/ospf_ism.c
ospfd/ospf_nsm.c
ospfd/ospf_opaque.c
ospfd/ospf_packet.c
ospfd/ospf_ri.c
ospfd/ospf_te.c
ospfd/ospfd.c
pbrd/pbr_zebra.c
pimd/pim_msdp.c
pimd/pim_upstream.c
ripd/ripd.c
ripngd/ripngd.c
tools/start-stop-daemon.c
zebra/if_sysctl.c
zebra/irdp_packet.c
zebra/kernel_socket.c
zebra/zebra_vty.c
zebra/zebra_vxlan.c

index 17d9bfb9360ddd15345a73690e707e3a8f0fb3dd..d9e2745827067df91a58024c3aeb534c751612b9 100644 (file)
@@ -32,7 +32,7 @@ THE SOFTWARE.
 #define CONFIG_NO 1
 #define CONFIG_YES 2
 
-/* babeld interface informations */
+/* babeld interface information */
 struct babel_interface {
     unsigned short flags;                     /* see below */
     unsigned short cost;
index d02d86f77b2a15befc6fb4e029f69e2ce715ce96..f26d3a8872a3695de40774b204a9355ae198ff18 100644 (file)
@@ -385,7 +385,7 @@ show_babel_main_configuration (struct vty *vty)
     vty_out (vty,
             "state file              = %s\n"
             "configuration file      = %s\n"
-            "protocol informations:\n"
+            "protocol information:\n"
             "  multicast address     = %s\n"
             "  port                  = %d\n"
             "vty address             = %s\n"
index 9523cca87ecde8b4cc9a9f69cde74e2c5d1f4c30..65a46bb9657b797b9a9a2ac9d39b34e6144cfaad 100644 (file)
@@ -1697,7 +1697,7 @@ int bgp_mp_reach_parse(struct bgp_attr_parser_args *args,
                                 * - for consistency in rx processing
                                 *
                                 * The following comment is to signal GCC this intention
-                                * and supress the warning
+                                * and suppress the warning
                                 */
        /* FALLTHRU */
        case BGP_ATTR_NHLEN_IPV4:
@@ -2624,7 +2624,7 @@ bgp_attr_parse_ret_t bgp_attr_parse(struct peer *peer, struct attr *attr,
                        return ret;
                }
 
-               /* If hard error occured immediately return to the caller. */
+               /* If hard error occurred immediately return to the caller. */
                if (ret == BGP_ATTR_PARSE_ERROR) {
                        flog_warn(EC_BGP_ATTRIBUTE_PARSE_ERROR,
                                  "%s: Attribute %s, parse error", peer->host,
index 86cee39a621cd9839de6a8ae766f0a03d954beb1..cf085e46fb1f1eaacc66d38217f85951b0d51d71 100644 (file)
@@ -689,7 +689,7 @@ int bgp_show_dampening_parameters(struct vty *vty, afi_t afi, safi_t safi)
                vty_out(vty, "Suppress penalty: %d\n", damp->suppress_value);
                vty_out(vty, "Max suppress time: %lld min\n",
                        (long long)damp->max_suppress_time / 60);
-               vty_out(vty, "Max supress penalty: %u\n", damp->ceiling);
+               vty_out(vty, "Max suppress penalty: %u\n", damp->ceiling);
                vty_out(vty, "\n");
        } else
                vty_out(vty, "dampening not enabled for %s\n",
index 7cebd0e484381a63b8661d317eb1344c8a9e9f1c..753ee6baf10043dad5d3966d66393c0d48091a7e 100644 (file)
@@ -171,7 +171,7 @@ static struct log_ref ferr_bgp_warn[] = {
        },
        {
                .code = EC_BGP_CAPABILITY_VENDOR,
-               .title = "BGP has recieved capability data specific to a particular vendor",
+               .title = "BGP has received capability data specific to a particular vendor",
                .description = "BGP has received a capability that is vendor specific and as such we have no knowledge of how to use this capability in FRR",
                .suggestion = "On peer turn off this feature"
        },
@@ -197,43 +197,43 @@ static struct log_ref ferr_bgp_err[] = {
                .code = EC_BGP_ATTR_FLAG,
                .title = "BGP attribute flag is incorrect",
                .description = "BGP attribute flag is set to the wrong value (Optional/Transitive/Partial)",
-               .suggestion = "Determine the soure of the attribute and determine why the attribute flag has been set incorrectly"
+               .suggestion = "Determine the source of the attribute and determine why the attribute flag has been set incorrectly"
        },
        {
                .code = EC_BGP_ATTR_LEN,
                .title = "BGP attribute length is incorrect",
                .description = "BGP attribute length is incorrect",
-               .suggestion = "Determine the soure of the attribute and determine why the attribute length has been set incorrectly"
+               .suggestion = "Determine the source of the attribute and determine why the attribute length has been set incorrectly"
        },
        {
                .code = EC_BGP_ATTR_ORIGIN,
                .title = "BGP attribute origin value invalid",
                .description = "BGP attribute origin value is invalid",
-               .suggestion = "Determine the soure of the attribute and determine why the origin attribute has been set incorrectly"
+               .suggestion = "Determine the source of the attribute and determine why the origin attribute has been set incorrectly"
        },
        {
                .code = EC_BGP_ATTR_MAL_AS_PATH,
                .title = "BGP as path is invalid",
                .description = "BGP as path has been malformed",
-               .suggestion = "Determine the soure of the update and determine why the as path has been set incorrectly"
+               .suggestion = "Determine the source of the update and determine why the as path has been set incorrectly"
        },
        {
                .code = EC_BGP_ATTR_FIRST_AS,
                .title = "BGP as path first as is invalid",
                .description = "BGP update has invalid first as in as path",
-               .suggestion = "Determine the soure of the update and determine why the as path first as value has been set incorrectly"
+               .suggestion = "Determine the source of the update and determine why the as path first as value has been set incorrectly"
        },
        {
                .code = EC_BGP_ATTR_PMSI_TYPE,
                .title = "BGP PMSI tunnel attribute type is invalid",
                .description = "BGP update has invalid type for PMSI tunnel",
-               .suggestion = "Determine the soure of the update and determine why the PMSI tunnel attribute type has been set incorrectly"
+               .suggestion = "Determine the source of the update and determine why the PMSI tunnel attribute type has been set incorrectly"
        },
        {
                .code = EC_BGP_ATTR_PMSI_LEN,
                .title = "BGP PMSI tunnel attribute length is invalid",
                .description = "BGP update has invalid length for PMSI tunnel",
-               .suggestion = "Determine the soure of the update and determine why the PMSI tunnel attribute length has been set incorrectly"
+               .suggestion = "Determine the source of the update and determine why the PMSI tunnel attribute length has been set incorrectly"
        },
        {
                .code = EC_BGP_PEER_GROUP,
@@ -269,7 +269,7 @@ static struct log_ref ferr_bgp_err[] = {
                .code = EC_BGP_JSON_MEM_ERROR,
                .title = "BGP unable to allocate memory for JSON output",
                .description = "BGP attempted to generate JSON output and was unable to allocate the memory required",
-               .suggestion = "Ensure that the device has adequate memory to suport the required functions"
+               .suggestion = "Ensure that the device has adequate memory to support the required functions"
        },
        {
                .code = EC_BGP_UPDGRP_ATTR_LEN,
index b67d93d4f5b3978daf761301977d065c5de2db20..574ece8cc53b6ae7d21af6edb6c09b10abe96aab 100644 (file)
@@ -1449,7 +1449,7 @@ static int update_evpn_type5_route_entry(struct bgp *bgp_def,
        }
 
        /*
-        * create a new route entry if one doesnt exist.
+        * create a new route entry if one doesn't exist.
         * Otherwise see if route attr has changed
         */
        if (!local_pi) {
@@ -5288,7 +5288,7 @@ int bgp_evpn_local_l3vni_add(vni_t l3vni, vrf_id_t vrf_id, struct ethaddr *rmac,
        }
        as = bgp_def->as;
 
-       /* if the BGP vrf instance doesnt exist - create one */
+       /* if the BGP vrf instance doesn't exist - create one */
        bgp_vrf = bgp_lookup_by_name(vrf_id_to_name(vrf_id));
        if (!bgp_vrf) {
 
index 90c9db3dfe0420db7967063e3cd039fc61e2c93f..29f9f64cca0d8c2bceef5fae6dd99112efa5a7dd 100644 (file)
@@ -3999,7 +3999,7 @@ DEFUN(test_withdraw_evpn_type4_route,
        }
 
        if (!bgp->peer_self) {
-               vty_out(vty, "%%BGP instance doesnt have self peer\n");
+               vty_out(vty, "%%BGP instance doesn't have self peer\n");
                return CMD_WARNING;
        }
 
index d17426e3ff703282c885dee3d51d0c829ee63c26..8aa35eddfcccede59b8b987cce51e98361bc0fe1 100644 (file)
@@ -931,7 +931,7 @@ static void bgp_update_delay_process_status_change(struct peer *peer)
        }
 }
 
-/* Called after event occured, this function change status and reset
+/* Called after event occurred, this function change status and reset
    read/write and timer thread. */
 void bgp_fsm_change_status(struct peer *peer, int status)
 {
index 96f3c8324f211f6fa2b7fbfda8e7770fa6fedf12..73a07c8232290e6b8545d11e12408c4f869dd810 100644 (file)
@@ -272,7 +272,7 @@ static void bgp_update_explicit_eors(struct peer *peer)
                                           PEER_STATUS_EOR_RECEIVED)) {
                                if (bgp_debug_neighbor_events(peer))
                                        zlog_debug(
-                                               "   afi %d safi %d didnt receive EOR",
+                                               "   afi %d safi %d didn't receive EOR",
                                                afi, safi);
                                return;
                        }
index a1c50a720f7c6f69b3d3d1d32acc6a7e19a74c3b..ecbe33ff8c51759ed393174add66746990638524 100644 (file)
@@ -2301,7 +2301,7 @@ DEFUN (bgp_default_show_hostname,
        "bgp default show-hostname",
        "BGP specific commands\n"
        "Configure BGP defaults\n"
-       "Show hostname in certain command ouputs\n")
+       "Show hostname in certain command outputs\n")
 {
        VTY_DECLVAR_CONTEXT(bgp, bgp);
        bgp_flag_set(bgp, BGP_FLAG_SHOW_HOSTNAME);
@@ -2314,7 +2314,7 @@ DEFUN (no_bgp_default_show_hostname,
        NO_STR
        "BGP specific commands\n"
        "Configure BGP defaults\n"
-       "Show hostname in certain command ouputs\n")
+       "Show hostname in certain command outputs\n")
 {
        VTY_DECLVAR_CONTEXT(bgp, bgp);
        bgp_flag_unset(bgp, BGP_FLAG_SHOW_HOSTNAME);
@@ -6016,7 +6016,7 @@ DEFUN (neighbor_allowas_in,
        NEIGHBOR_STR
        NEIGHBOR_ADDR_STR2
        "Accept as-path with my AS present in it\n"
-       "Number of occurances of AS number\n"
+       "Number of occurences of AS number\n"
        "Only accept my AS in the as-path if the route was originated in my AS\n")
 {
        int idx_peer = 1;
@@ -6050,7 +6050,7 @@ ALIAS_HIDDEN(
        "neighbor <A.B.C.D|X:X::X:X|WORD> allowas-in [<(1-10)|origin>]",
        NEIGHBOR_STR NEIGHBOR_ADDR_STR2
        "Accept as-path with my AS present in it\n"
-       "Number of occurances of AS number\n"
+       "Number of occurences of AS number\n"
        "Only accept my AS in the as-path if the route was originated in my AS\n")
 
 DEFUN (no_neighbor_allowas_in,
@@ -6060,7 +6060,7 @@ DEFUN (no_neighbor_allowas_in,
        NEIGHBOR_STR
        NEIGHBOR_ADDR_STR2
        "allow local ASN appears in aspath attribute\n"
-       "Number of occurances of AS number\n"
+       "Number of occurences of AS number\n"
        "Only accept my AS in the as-path if the route was originated in my AS\n")
 {
        int idx_peer = 2;
@@ -6082,7 +6082,7 @@ ALIAS_HIDDEN(
        "no neighbor <A.B.C.D|X:X::X:X|WORD> allowas-in [<(1-10)|origin>]",
        NO_STR NEIGHBOR_STR NEIGHBOR_ADDR_STR2
        "allow local ASN appears in aspath attribute\n"
-       "Number of occurances of AS number\n"
+       "Number of occurences of AS number\n"
        "Only accept my AS in the as-path if the route was originated in my AS\n")
 
 DEFUN (neighbor_ttl_security,
@@ -9607,7 +9607,7 @@ static void bgp_show_peer(struct vty *vty, struct peer *p, bool use_json,
                                                                json_object_string_add(
                                                                        json_nxt,
                                                                        print_store,
-                                                                       "recieved");
+                                                                       "received");
                                                        }
                                                }
                                                json_object_object_add(
@@ -10215,7 +10215,7 @@ static void bgp_show_peer(struct vty *vty, struct peer *p, bool use_json,
                        json_object_object_add(
                                json_neigh, "gracefulRestartInfo", json_grace);
                } else {
-                       vty_out(vty, "  Graceful restart informations:\n");
+                       vty_out(vty, "  Graceful restart information:\n");
                        if (p->status == Established) {
                                vty_out(vty, "    End-of-RIB send: ");
                                FOREACH_AFI_SAFI (afi, safi) {
index 74d3eb7bbdccb605e79cf65151c4e08cbc11a5f2..a5977a6ebbe51b8ff5ba775b7185083b4562e5d0 100644 (file)
@@ -136,7 +136,7 @@ These following options control the daemon's VTY (interactive command line) inte
 
    NB: Unlike the other options, this option specifies a directory, not a full path.
 
-   This option is primarily used by the SNAP packaging system, its semantics may change.  It should not be neccessary in most other scenarios.
+   This option is primarily used by the SNAP packaging system, its semantics may change.  It should not be necessary in most other scenarios.
 
 MODULE LOADING
 --------------
index a8a9301588f1181eafc429cabf9c37d6f56e6fb2..cfb368bf4455ae8f588b6b12383a4a6125084025 100644 (file)
@@ -33,7 +33,7 @@ OPTIONS available for the |DAEMON| command:
 
    Set netlink receive buffer size. There are cases where zebra daemon can't handle flood of netlink messages from kernel. If you ever see "recvmsg overrun" messages in zebra log, you are in trouble.
 
-   Solution is to increase receive buffer of netlink socket. Note that kernel < 2.6.14 doesn't allow to increase it over maximum value defined in /proc/sys/net/core/rmem_max. If you want to do it, you have to increase maximum before starting zebra.
+   Solution is to increase receive buffer of netlink socket. Note that kernel < 2.6.14 doesn't allow increasing it over maximum value defined in /proc/sys/net/core/rmem_max. If you want to do it, you have to increase maximum before starting zebra.
 
    Note that this affects Linux only.
 
index 3d84c82179ecd31a95c2883b131f3b55c400c8a8..895a141e4a146c140b3fc5b45e6d047222bfccdf 100644 (file)
@@ -152,7 +152,7 @@ enum eigrp_fsm_states {
 enum eigrp_fsm_events {
        /*
         * Input event other than query from succ,
-        * FC is not satisified
+        * FC is not satisfied
         */
        EIGRP_FSM_EVENT_NQ_FCN,
 
@@ -171,7 +171,7 @@ enum eigrp_fsm_events {
        /* Query from succ while in active state */
        EIGRP_FSM_EVENT_QACT,
 
-       /* last reply, FC not satisified */
+       /* last reply, FC not satisfied */
        EIGRP_FSM_EVENT_LR_FCN,
 
        /*
index bbe2b88223f3cb013c7074c310caf30ae94f46dd..27e02630a655d91c7d05912af872031250f77f26 100644 (file)
@@ -228,7 +228,7 @@ void show_ip_eigrp_interface_detail(struct vty *vty, struct eigrp *eigrp,
                "Un/reliable mcasts: ", 0, "/", 0, "Un/reliable ucasts: ", 0,
                "/", 0);
        vty_out(vty, "%-2s %s %d %s %d %s %d \n", "", "Mcast exceptions: ", 0,
-               "  CR packets: ", 0, "  ACKs supressed: ", 0);
+               "  CR packets: ", 0, "  ACKs suppressed: ", 0);
        vty_out(vty, "%-2s %s %d %s %d \n", "", "Retransmissions sent: ", 0,
                "Out-of-sequence rcvd: ", 0);
        vty_out(vty, "%-2s %s %s %s \n", "", "Authentication mode is ", "not",
index f955e6df0f7fb917945a34780df728842d9848d4..374114cf559dd279fa4935c895d8e8dddb756df9 100644 (file)
@@ -222,9 +222,9 @@ static const char *fsm_state2str(enum eigrp_fsm_events event)
        case EIGRP_FSM_EVENT_LR:
                return "Last Reply Event";
        case EIGRP_FSM_EVENT_Q_FCN:
-               return "Query Event Feasability not satisified";
+               return "Query Event Feasability not satisfied";
        case EIGRP_FSM_EVENT_LR_FCS:
-               return "Last Reply Event Feasability satisified";
+               return "Last Reply Event Feasability satisfied";
        case EIGRP_FSM_EVENT_DINC:
                return "Distance Increase Event";
        case EIGRP_FSM_EVENT_QACT:
index 1c4ca249ee57b6c0c95f4fc068e021cf7aa8c402..b6f751463a7ce187478f50f557ba319a456c0213 100644 (file)
@@ -887,7 +887,7 @@ static int isis_spf_preload_tent(struct isis_spftree *spftree,
                                case ISIS_SYSTYPE_UNKNOWN:
                                default:
                                        zlog_warn(
-                                               "isis_spf_preload_tent unknow adj type");
+                                               "isis_spf_preload_tent unknown adj type");
                                }
                        }
                        list_delete(&adj_list);
index 8eed0899000c434469be782e488cf8f3492d3688..c24e1917ccf7b974cf859caf24d01b6930d8758b 100644 (file)
@@ -156,7 +156,7 @@ DEFPY  (ldp_dual_stack_transport_connection_prefer_ipv4,
        NO_STR
        "Configure dual stack parameters\n"
        "Configure TCP transport parameters\n"
-       "Configure prefered address family for TCP transport connection with neighbor\n"
+       "Configure preferred address family for TCP transport connection with neighbor\n"
        "IPv4\n")
 {
        return (ldp_vty_trans_pref_ipv4(vty, no));
index 12f9cb0ccf94d580d5b1e259c5167be2d52564c8..b4d74f1950ec69b78ea1b7a1ec2ace93471ee69b 100644 (file)
@@ -259,7 +259,7 @@ embedscope(struct sockaddr_in6 *sin6)
        if (IN6_IS_SCOPE_EMBED(&sin6->sin6_addr)) {
                memcpy(&tmp16, &sin6->sin6_addr.s6_addr[2], sizeof(tmp16));
                if (tmp16 != 0) {
-                       log_warnx("%s: address %s already has embeded scope %u",
+                       log_warnx("%s: address %s already has embedded scope %u",
                            __func__, log_sockaddr(sin6), ntohs(tmp16));
                }
                tmp16 = htons(sin6->sin6_scope_id);
index 1dfe583caf7743744a35c49362e7c5abe6d1015b..178c203f5e9f64ca66fdcbe617a95e8723ef570f 100644 (file)
--- a/lib/bfd.c
+++ b/lib/bfd.c
@@ -134,7 +134,7 @@ void bfd_peer_sendmsg(struct zclient *zclient, struct bfd_info *bfd_info,
        int ret;
        int len;
 
-       /* Individual reg/dereg messages are supressed during shutdown. */
+       /* Individual reg/dereg messages are suppressed during shutdown. */
        if (CHECK_FLAG(bfd_gbl.flags, BFD_GBL_FLAG_IN_SHUTDOWN)) {
                if (bfd_debug)
                        zlog_debug(
index fbff1e67f4331c098f2e737d209989403e1ef3d4..de65c8bd985cfd7ac3895a4d8af8f755dae258b9 100644 (file)
@@ -355,7 +355,7 @@ struct cmd_node {
 #define IN_STR  "Filter incoming routing updates\n"
 #define V4NOTATION_STR "specify by IPv4 address notation(e.g. 0.0.0.0)\n"
 #define OSPF6_NUMBER_STR "Specify by number\n"
-#define INTERFACE_STR "Interface infomation\n"
+#define INTERFACE_STR "Interface information\n"
 #define IFNAME_STR "Interface name(e.g. ep0)\n"
 #define IP6_STR "IPv6 Information\n"
 #define OSPF6_STR "Open Shortest Path First (OSPF) for IPv6\n"
index 03ad974da6ba22cceece8d84148a134a03889901..ad83ef1e5182109657c6c04eb82d6d81019cf621 100644 (file)
@@ -89,8 +89,8 @@ static struct log_ref ferr_lib_err[] = {
        {
                .code = EC_LIB_SOCKET,
                .title = "Socket Error",
-               .description = "When attempting to access a socket a system error has occured and we were unable to properly complete the request",
-               .suggestion = "Ensure that there are sufficient system resources available and ensure that the frr user has sufficient permisions to work.  If necessary open an Issue",
+               .description = "When attempting to access a socket a system error has occurred and we were unable to properly complete the request",
+               .suggestion = "Ensure that there are sufficient system resources available and ensure that the frr user has sufficient permissions to work.  If necessary open an Issue",
        },
        {
                .code = EC_LIB_ZAPI_MISSMATCH,
index c9dd60dce0a87cb9384c160acae49dec7d01d2b1..61469856105fb0b35a2108172ca41672bde19412 100644 (file)
@@ -171,7 +171,7 @@ static inline char *label2str(mpls_label_t label, char *buf, size_t len)
                strlcpy(buf, "Router Alert", len);
                return (buf);
        case MPLS_LABEL_IPV6_EXPLICIT_NULL:
-               strlcpy(buf, "IPv6 Explict Null", len);
+               strlcpy(buf, "IPv6 Explicit Null", len);
                return (buf);
        case MPLS_LABEL_IMPLICIT_NULL:
                strlcpy(buf, "implicit-null", len);
index bee82a067eaab49ae1a3ee531a439cce51fef3d2..af4f41f37ca380ec45a2f11267ef78cff7df7bf4 100644 (file)
@@ -356,7 +356,7 @@ int sockopt_ttl(int family, int sock, int ttl)
  * Which on linux is a no-op since it is enabled by
  * default and on BSD it uses TCP_NOPUSH to do
  * the same thing( which it was not configured to
* use).  This cleanup of the api occured on 8/1/17
  * I imagine if after more than 1 year of no-one
  * complaining, and a major upgrade release we
  * can deprecate and remove this function call
index 27b0f0c4f035338c7186790c9bdd7f69fad7e8fd..37cbe9187cd997117b985e3c27dfd45ee761477e 100644 (file)
@@ -22,7 +22,7 @@
 #   another object file.
 #
 #   There are four known schemes of declaring weak symbols; each scheme is
-#   checked in turn, and the first one found is prefered. Note that only one
+#   checked in turn, and the first one found is preferred. Note that only one
 #   of the mentioned preprocessor macros will be defined!
 #
 #   1. Function attributes
index 1890e9bdc39aba25813a53467f337d4ceaf18df2..53d545a24bceef63081da5cdac01d800f64a19e2 100644 (file)
@@ -321,7 +321,7 @@ int ospf6_abr_originate_summary_to_area(struct ospf6_route *route,
 
        /* if this is a route to ASBR */
        if (route->type == OSPF6_DEST_TYPE_ROUTER) {
-               /* Only the prefered best path is considered */
+               /* Only the preferred best path is considered */
                if (!CHECK_FLAG(route->flag, OSPF6_ROUTE_BEST)) {
                        if (is_debug)
                                zlog_debug(
index c848a16aa94b581973865873a776629850b7a357..bc52864313ed7c3072dc4b5a07767115ed7bacec 100644 (file)
@@ -772,7 +772,7 @@ DEFUN (show_ipv6_ospf6_spf_tree,
        SHOW_STR
        IP6_STR
        OSPF6_STR
-       "Shortest Path First caculation\n"
+       "Shortest Path First calculation\n"
        "Show SPF tree\n")
 {
        struct listnode *node;
@@ -807,7 +807,7 @@ DEFUN (show_ipv6_ospf6_area_spf_tree,
        OSPF6_STR
        OSPF6_AREA_STR
        OSPF6_AREA_ID_STR
-       "Shortest Path First caculation\n"
+       "Shortest Path First calculation\n"
        "Show SPF tree\n")
 {
        int idx_ipv4 = 4;
index ad9b3efe6ee7f1d17d410751f7395004c858fe03..9fd9a70c78e9e0300eb0cddcebf50c9dac82883c 100644 (file)
@@ -277,7 +277,7 @@ static int ospf_wait_timer(struct thread *thread)
        return 0;
 }
 
/* Hook function called after ospf ISM event is occured. And vty's
    network command invoke this function after making interface
    structure. */
 static void ism_timer_set(struct ospf_interface *oi)
index 91d187f412a192e6234d1a4bed04300f0a1691ba..f7c73fee3397914b2d4ed7b19eef86e2f64a3b1d 100644 (file)
@@ -94,7 +94,7 @@ static int ospf_db_desc_timer(struct thread *thread)
        return 0;
 }
 
/* Hook function called after ospf NSM event is occured.
  *
  * Set/clear any timers whose condition is implicit to the neighbour
  * state. There may be other timers which are set/unset according to other
index 7f96299768ed50ada4caf4b4b556bf61523605df..147773ce235ecb1c66410286110d5308676cad7c 100644 (file)
@@ -500,7 +500,7 @@ struct opaque_info_per_type {
        /* Collection of callback functions for this opaque-type. */
        struct ospf_opaque_functab *functab;
 
-       /* List of Opaque-LSA control informations per opaque-id. */
+       /* List of Opaque-LSA control information per opaque-id. */
        struct list *id_list;
 };
 
index 79b464880555a3c2f1fb6dccab720b0013c5b4a6..3bb3b79a6a728481e75f041f88c5ad58cb786a3c 100644 (file)
@@ -3368,7 +3368,7 @@ static int ospf_make_db_desc(struct ospf_interface *oi,
                                if (IS_OPAQUE_LSA(lsa->data->type)
                                    && (!CHECK_FLAG(options, OSPF_OPTION_O))) {
                                        /* Suppress advertising
-                                        * opaque-informations. */
+                                        * opaque-information. */
                                        /* Remove LSA from DB summary list. */
                                        ospf_lsdb_delete(lsdb, lsa);
                                        continue;
index 3b0319b5912b880a64618258f874825c08e2718d..bef16761f2831346f0b8700222924330aac2ac4a 100644 (file)
@@ -591,7 +591,7 @@ static int is_mandated_params_set(struct ospf_router_info ori)
  * @param enable To activate or not Segment Routing router Information flooding
  * @param size   Size of Label Range i.e. SRGB size
  * @param lower  Lower bound of the Label Range i.e. SRGB first label
- * @param msd    Maximum label Stack Depth suported by the router
+ * @param msd    Maximum label Stack Depth supported by the router
  *
  * @return none
  */
index f43038ab8de2986bd1cb26555c7da328a6acce08..02698d770a760725128098798eaf4ed139313991 100644 (file)
@@ -2406,7 +2406,7 @@ DEFUN (no_ospf_mpls_te_inter_as,
                                ospf_mpls_te_lsa_schedule(lp, FLUSH_THIS_LSA);
        }
 
-       /* Deregister the Callbacks for Inter-AS suport */
+       /* Deregister the Callbacks for Inter-AS support */
        ospf_mpls_te_unregister();
 
        return CMD_SUCCESS;
index dc54f04c07473a69521a6c34e19313813afde006..aa40dd0ebcb4878faee16aadfd4c3f140cfec06a 100644 (file)
@@ -171,7 +171,7 @@ void ospf_router_id_update(struct ospf *ospf)
 
                /* Flush (inline) all external LSAs which now match the new
                   router-id,
-                  need to adjust the OSPF_LSA_SELF flag, so the flush doesnt
+                  need to adjust the OSPF_LSA_SELF flag, so the flush doesn't
                   hit
                   asserts in ospf_refresher_unregister_lsa(). This step is
                   needed
index 25d64238bfd3b6ced06a290e6795e8bad96d93db..b7391a171a653215e09d8b23bb99485bd82a3ae4 100644 (file)
@@ -207,13 +207,13 @@ static int rule_notify_owner(int command, struct zclient *zclient,
 
        switch (note) {
        case ZAPI_RULE_FAIL_INSTALL:
-               DEBUGD(&pbr_dbg_zebra, "%s: Recieved RULE_FAIL_INSTALL",
+               DEBUGD(&pbr_dbg_zebra, "%s: Received RULE_FAIL_INSTALL",
                       __PRETTY_FUNCTION__);
                pbrms->installed &= ~installed;
                break;
        case ZAPI_RULE_INSTALLED:
                pbrms->installed |= installed;
-               DEBUGD(&pbr_dbg_zebra, "%s: Recived RULE_INSTALLED",
+               DEBUGD(&pbr_dbg_zebra, "%s: Received RULE_INSTALLED",
                       __PRETTY_FUNCTION__);
                break;
        case ZAPI_RULE_FAIL_REMOVE:
index 807ad2bd129279a9646311c86719cdc6c4d6745b..7e072e6ade4037b594b4e9daf47e9f62a1f0406f 100644 (file)
@@ -74,7 +74,7 @@ static int pim_msdp_sa_adv_timer_cb(struct thread *t)
        struct pim_instance *pim = THREAD_ARG(t);
 
        if (PIM_DEBUG_MSDP_EVENTS) {
-               zlog_debug("MSDP SA advertisment timer expired");
+               zlog_debug("MSDP SA advertisement timer expired");
        }
 
        pim_msdp_sa_adv_timer_setup(pim, true /* start */);
index e5f5b34f2f857da8fc484d7c0f8599b07b3416d8..cd5b632dedb95d006a1f86d63afee0331831d614 100644 (file)
@@ -462,7 +462,7 @@ static int pim_upstream_could_register(struct pim_upstream *up)
        return 0;
 }
 
-/* Source registration is supressed for SSM groups. When the SSM range changes
+/* Source registration is suppressed for SSM groups. When the SSM range changes
  * we re-revaluate register setup for existing upstream entries */
 void pim_upstream_register_reevaluate(struct pim_instance *pim)
 {
index 444a09914c16a7a51a5e3fd00a7d544055be4da1..dd0d17ee47c0cf8dd94769ef592c7990dcf24526 100644 (file)
@@ -1238,7 +1238,7 @@ static void rip_response_process(struct rip_packet *packet, int size,
                   Ciscos before the 'ip subnet zero' option, it would be almost
                   right too :-)
 
-                  Cisco summarize ripv1 advertisments to the classful boundary
+                  Cisco summarize ripv1 advertisements to the classful boundary
                   (/16 for class B's) except when the RIP packet does to inside
                   the classful network in question.  */
 
@@ -2513,7 +2513,7 @@ static void rip_update_process(int route_type)
                                                      VRF_DEFAULT);
                        if (!connected) {
                                zlog_warn(
-                                       "Neighbor %s doesnt have connected interface!",
+                                       "Neighbor %s doesn't have connected interface!",
                                        inet_ntoa(p->u.prefix4));
                                continue;
                        }
index 08dc3d8b4d330dd1502960e29f7040679d4156a3..2cbbbae7f547faf5f29d2413802f519e6fdbc522 100644 (file)
@@ -1560,7 +1560,7 @@ void ripng_output_process(struct interface *ifp, struct sockaddr_in6 *to,
                    && rinfo->suppress == 0) {
                        /* If no route-map are applied, the RTE will be these
                         * following
-                        * informations.
+                        * information.
                         */
                        p = (struct prefix_ipv6 *)&rp->p;
                        rinfo->metric_out = rinfo->metric;
@@ -1701,7 +1701,7 @@ void ripng_output_process(struct interface *ifp, struct sockaddr_in6 *to,
                    && aggregate->suppress == 0) {
                        /* If no route-map are applied, the RTE will be these
                         * following
-                        * informations.
+                        * information.
                         */
                        p = (struct prefix_ipv6 *)&rp->p;
                        aggregate->metric_set = 0;
index 8daeda7402a1b98cd7285b13cf554ee921540486..f2a1e9434bc9d2d848ec4a6591844986444c59f8 100644 (file)
@@ -1013,7 +1013,7 @@ int main(int argc, char **argv)
        if (background) { /* ok, we need to detach this process */
                int i, fd;
                if (quietmode < 0)
-                       printf("Detatching to start %s...", startas);
+                       printf("Detaching to start %s...", startas);
                i = fork();
                if (i < 0) {
                        fatal("Unable to fork.\n");
index 3f918c361aafd506645186d79562fc69239955cf..44afd266bc1e1bfc0b0d8354163cf79c8aaa4ac4 100644 (file)
@@ -61,7 +61,7 @@ void ifstat_update_sysctl(void)
        /* We free this memory at the end of this function. */
        ref = buf = XMALLOC(MTYPE_TMP, bufsiz);
 
-       /* Fetch interface informations into allocated buffer. */
+       /* Fetch interface information into allocated buffer. */
        if (sysctl(mib, MIBSIZ, buf, &bufsiz, NULL, 0) < 0) {
                flog_warn(EC_ZEBRA_SYSCTL_FAILED, "sysctl error by %s",
                          safe_strerror(errno));
@@ -113,7 +113,7 @@ void interface_list(struct zebra_ns *zns)
        /* We free this memory at the end of this function. */
        ref = buf = XMALLOC(MTYPE_TMP, bufsiz);
 
-       /* Fetch interface informations into allocated buffer. */
+       /* Fetch interface information into allocated buffer. */
        if (sysctl(mib, MIBSIZ, buf, &bufsiz, NULL, 0) < 0) {
                flog_err_sys(EC_ZEBRA_IFLIST_FAILED,
                             "Could not enumerate interfaces: %s",
index 2b5bf04adee6613d6bc8458c23c14de1041e1f21..bebccd716820403b20c856e07e8f7da6ba0d75bc 100644 (file)
@@ -97,7 +97,7 @@ static void parse_irdp_packet(char *p, int len, struct interface *ifp)
 
        if (len != iplen) {
                flog_err(EC_ZEBRA_IRDP_LEN_MISMATCH,
-                        "IRDP: RX length doesnt match IP length");
+                        "IRDP: RX length doesn't match IP length");
                return;
        }
 
@@ -108,7 +108,7 @@ static void parse_irdp_packet(char *p, int len, struct interface *ifp)
                return;
        }
 
/* XXX: RAW doesnt receive link-layer, surely? ??? */
        /* Check so we don't checksum packets longer than oure RX_BUF - (ethlen
         +
         len of IP-header) 14+20 */
index 8df5a37640674abcff43818c88de686bbd756cbe..9c3d9adefbc96cde7887e6a73eeda9255d6ee25f 100644 (file)
@@ -469,7 +469,7 @@ int ifm_read(struct if_msghdr *ifm)
                if (ifnlen && (strncmp(ifp->name, ifname, IFNAMSIZ) != 0)) {
                        if (IS_ZEBRA_DEBUG_KERNEL)
                                zlog_debug(
-                                       "%s: ifp name %s doesnt match sdl name %s",
+                                       "%s: ifp name %s doesn't match sdl name %s",
                                        __func__, ifp->name, ifname);
                        ifp = NULL;
                }
index fdedb30f84ec55805f2e1746097ccd9a752fbbb7..cf704f24be3777f08c75db43ed9be9d5075c866c 100644 (file)
@@ -295,7 +295,7 @@ static void vty_show_ip_route_detail(struct vty *vty, struct route_node *rn,
                                if (vrf)
                                        vty_out(vty, "(vrf %s)", vrf->name);
                                else
-                                       vty_out(vty, "(vrf UKNOWN)");
+                                       vty_out(vty, "(vrf UNKNOWN)");
                        }
 
                        if (CHECK_FLAG(nexthop->flags, NEXTHOP_FLAG_DUPLICATE))
@@ -670,7 +670,7 @@ static void vty_show_ip_route(struct vty *vty, struct route_node *rn,
                        if (vrf)
                                vty_out(vty, "(vrf %s)", vrf->name);
                        else
-                               vty_out(vty, "(vrf UKNOWN)");
+                               vty_out(vty, "(vrf UNKNOWN)");
                }
 
                if (!CHECK_FLAG(nexthop->flags, NEXTHOP_FLAG_ACTIVE))
index fe182780bebcfba09212a5887be3292f965b7537..974b4d5befb3323265b6dfd95f1f63d7c06eca2c 100644 (file)
@@ -1855,7 +1855,7 @@ static int zvni_gw_macip_del(struct interface *ifp, zebra_vni_t *zvni,
        /* mac entry should be present */
        mac = zvni_mac_lookup(zvni, &n->emac);
        if (!mac) {
-               zlog_debug("MAC %s doesnt exists for neigh %s on VNI %u",
+               zlog_debug("MAC %s doesn't exist for neigh %s on VNI %u",
                           prefix_mac2str(&n->emac, buf1, sizeof(buf1)),
                           ipaddr2str(ip, buf2, sizeof(buf2)), zvni->vni);
                return -1;
@@ -4564,7 +4564,7 @@ void zebra_vxlan_print_specific_rmac_l3vni(struct vty *vty, vni_t l3vni,
                if (use_json)
                        vty_out(vty, "{}\n");
                else
-                       vty_out(vty, "%% L3-VNI %u doesnt exist\n", l3vni);
+                       vty_out(vty, "%% L3-VNI %u doesn't exist\n", l3vni);
                return;
        }
 
@@ -4574,7 +4574,7 @@ void zebra_vxlan_print_specific_rmac_l3vni(struct vty *vty, vni_t l3vni,
                        vty_out(vty, "{}\n");
                else
                        vty_out(vty,
-                               "%% Requested RMAC doesnt exist in L3-VNI %u",
+                               "%% Requested RMAC doesn't exist in L3-VNI %u",
                                l3vni);
                return;
        }
@@ -356,7 +356,7 @@ int sockopt_ttl(int family, int sock, int ttl)
  * default and on BSD it uses TCP_NOPUSH to do
  * the same thing( which it was not configured to
- * use).  This cleanup of the api occured on 8/1/17
+ * use).  This cleanup of the api occurred on 8/1/17
  * I imagine if after more than 1 year of no-one
  * complaining, and a major upgrade release we
@@ -277,7 +277,7 @@ static int ospf_wait_timer(struct thread *thread)
 }
 
-/* Hook function called after ospf ISM event is occured. And vty's
+/* Hook function called after ospf ISM event is occurred. And vty's
    network command invoke this function after making interface
    structure. */
@@ -94,7 +94,7 @@ static int ospf_db_desc_timer(struct thread *thread)
 }
 
-/* Hook function called after ospf NSM event is occured.
+/* Hook function called after ospf NSM event is occurred.
  *
  * Set/clear any timers whose condition is implicit to the neighbour
@@ -108,7 +108,7 @@ static void parse_irdp_packet(char *p, int len, struct interface *ifp)
        }
 
-       /* XXX: RAW doesnt receive link-layer, surely? ??? */
+       /* XXX: RAW doesn't receive link-layer, surely? ??? */
        /* Check so we don't checksum packets longer than oure RX_BUF - (ethlen
         +